@@ -12,7 +12,7 @@ def format(value):
         case "true":
             return True
         case _:
-            return value
+            return value.replace("\r\n", "\n").replace("\n\n", "\n")
 
 
 class ApplicationSerializer(serializers.HyperlinkedModelSerializer):
@@ -39,15 +39,74 @@ class ApplicationDetailSerializer(serializers.HyperlinkedModelSerializer):
         serialized["apps"]["hosts"][application["slug"]] = {
             "graphics": {
                 "client": application["client_url"],
-                "title": application["application_title"],
                 "canva": application["repository"],
-                "logo": application["application_logo"],
             },
             "data": {"api": application["api_url"], "with": federation},
             "packages": [],
             "components": [],
         }
 
+        if application["application_title"]:
+            serialized["apps"]["hosts"][application["slug"]]["graphics"][
+                "title"
+            ] = application["application_title"]
+
+        if application["application_logo"]:
+            serialized["apps"]["hosts"][application["slug"]]["graphics"][
+                "logo"
+            ] = application["application_logo"]
+
+        if len(application["graphics"]) > 0:
+            for applicationGraphic in application["graphics"]:
+                if applicationGraphic.obj.primary_key:
+                    if (
+                        applicationGraphic.obj.primary_key
+                        not in serialized["apps"]["hosts"][application["slug"]][
+                            "graphics"
+                        ]
+                    ):
+                        serialized["apps"]["hosts"][application["slug"]]["graphics"][
+                            applicationGraphic.obj.primary_key
+                        ] = {}
+                    serialized["apps"]["hosts"][application["slug"]]["graphics"][
+                        applicationGraphic.obj.primary_key
+                    ][applicationGraphic.obj.key] = format(applicationGraphic.obj.value)
+                else:
+                    serialized["apps"]["hosts"][application["slug"]]["graphics"][
+                        applicationGraphic.obj.key
+                    ] = format(applicationGraphic.obj.value)
+
+        if len(application["services"]) > 0:
+            serialized["apps"]["hosts"][application["slug"]]["services"] = {}
+            for applicationService in application["services"]:
+                if applicationService.obj.primary_key:
+                    if (
+                        applicationService.obj.primary_key
+                        not in serialized["apps"]["hosts"][application["slug"]][
+                            "services"
+                        ]
+                    ):
+                        serialized["apps"]["hosts"][application["slug"]]["services"][
+                            applicationService.obj.primary_key
+                        ] = {}
+                    serialized["apps"]["hosts"][application["slug"]]["services"][
+                        applicationService.obj.primary_key
+                    ][applicationService.obj.key] = format(applicationService.obj.value)
+                else:
+                    serialized["apps"]["hosts"][application["slug"]]["services"][
+                        applicationService.obj.key
+                    ] = format(applicationService.obj.value)
+
+        if len(application["npms"]) > 0:
+            serialized["apps"]["hosts"][application["slug"]]["npm"] = []
+            for applicationNPM in application["npms"]:
+                serialized["apps"]["hosts"][application["slug"]]["npm"].append(
+                    {
+                        "package": applicationNPM.obj.package,
+                        "version": applicationNPM.obj.version,
+                    }
+                )
+
         for applicationComponent in application["components"]:
             component = Component.objects.get(id=applicationComponent.obj.component_id)
             insertComponent = {
@@ -139,6 +198,9 @@ class ApplicationDetailSerializer(serializers.HyperlinkedModelSerializer):
             "client_url",
             "application_title",
             "application_logo",
+            "services",
+            "graphics",
+            "npms",
             "components",
             "packages",
             "repository",
